# Generated by Django 5.2.10 on 2026-03-07 16:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_resaas', '0002_layoutsetting_entidade_layout_settings_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='layoutsetting',
            options={'verbose_name': 'LayoutSetting', 'verbose_name_plural': 'LayoutSettings'},
        ),
        migrations.RemoveField(
            model_name='layoutsetting',
            name='accent',
        ),
        migrations.RemoveField(
            model_name='layoutsetting',
            name='dark',
        ),
        migrations.RemoveField(
            model_name='layoutsetting',
            name='info',
        ),
        migrations.RemoveField(
            model_name='layoutsetting',
            name='negative',
        ),
        migrations.RemoveField(
            model_name='layoutsetting',
            name='positive',
        ),
        migrations.RemoveField(
            model_name='layoutsetting',
            name='primary',
        ),
        migrations.RemoveField(
            model_name='layoutsetting',
            name='secondary',
        ),
        migrations.RemoveField(
            model_name='layoutsetting',
            name='warning',
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='animations',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='button_dense',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='button_round',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='button_style',
            field=models.CharField(choices=[('flat', 'Flat'), ('outline', 'Outline'), ('unelevated', 'Unelevated'), ('push', 'Push')], default='unelevated', max_length=20),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='card_bordered',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='card_flat',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='dark_mode',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='dense',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='density',
            field=models.CharField(choices=[('dense', 'Dense'), ('normal', 'Normal'), ('comfortable', 'Comfortable')], default='normal', max_length=20),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='elevated',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='input_dense',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='input_style',
            field=models.CharField(choices=[('outlined', 'Outlined'), ('filled', 'Filled'), ('standout', 'Standout')], default='outlined', max_length=20),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='nome',
            field=models.CharField(default=None, max_length=100),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='ripple',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='rounded',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='sidebar_mini',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='sidebar_width',
            field=models.IntegerField(default=260),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='square',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='toolbar_dense',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='layoutsetting',
            name='toolbar_elevated',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name='theme',
            name='accent',
            field=models.CharField(default='#9C250B0', max_length=50),
        ),
        migrations.AlterField(
            model_name='theme',
            name='dark',
            field=models.CharField(default='#1d1d1d', max_length=50),
        ),
        migrations.AlterField(
            model_name='theme',
            name='info',
            field=models.CharField(default='#31CCEC', max_length=50),
        ),
        migrations.AlterField(
            model_name='theme',
            name='negative',
            field=models.CharField(default='#C10015', max_length=50),
        ),
        migrations.AlterField(
            model_name='theme',
            name='positive',
            field=models.CharField(default='#21BA45', max_length=50),
        ),
        migrations.AlterField(
            model_name='theme',
            name='primary',
            field=models.CharField(default='#19506D2', max_length=50),
        ),
        migrations.AlterField(
            model_name='theme',
            name='secondary',
            field=models.CharField(default='#26A69A', max_length=50),
        ),
        migrations.AlterField(
            model_name='theme',
            name='warning',
            field=models.CharField(default='#F2C0350', max_length=50),
        ),
    ]
